package com.example.reservationapp

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.viewModels
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.ui.Modifier
import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.reservationapp.api.RepositoryClassCasual
import com.example.reservationapp.api.RetrofitInstance
import com.example.reservationapp.screens.ListPage
import com.example.reservationapp.screens.Login
import com.example.reservationapp.screens.OTPverify
import com.example.reservationapp.screens.Registration
import com.example.reservationapp.ui.theme.ReservationAppTheme
import com.example.reservationapp.viewmodels.NewViewModel
import com.example.reservationapp.viewmodels.ViewModelMain

class MainActivity : ComponentActivity() {

    // Creating some provider
    private val newViewModel by viewModels<NewViewModel>(factoryProducer = {
        object  : ViewModelProvider.Factory{
            override fun <T : ViewModel> create(modelClass: Class<T>): T {
                return NewViewModel(RepositoryClassCasual(RetrofitInstance.api)) as T
            }
        }
    })

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {

            ReservationAppTheme {
                // A surface container using the 'background' color from the theme

                val navController = rememberNavController()

                Surface (
                    modifier = Modifier.fillMaxSize(),
                    color = MaterialTheme.colorScheme.background
                ){
                    
                    NavHost(
                        navController = navController,
                        startDestination = "LoginScreen" ){

                        composable("LoginScreen"){
                            Login(navController, viewModelMain = newViewModel)
                        }

                        composable("RegistrationScreen"){
                            Registration (navController, viewModel = newViewModel )
                        }

                        composable("OTPScreen") {
                            OTPverify(navController, viewModelMain = newViewModel)
                        }

                        composable("ListPageScreen"){
                            ListPage (navController, viewModelMain = newViewModel )
                        }
                    }


                }

            }

        }
    }
}


