package com.example.reservationapp.screens


import android.widget.Toast
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.ClickableText
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Email
import androidx.compose.material3.Button
import androidx.compose.material3.Icon
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.AnnotatedString
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.reservationapp.viewmodels.NewViewModel


@Composable
fun Login(navController: NavController, viewModelMain: NewViewModel){
    Column ( modifier = Modifier
        .fillMaxSize()
        .padding(horizontal = 30.dp, vertical = 140.dp),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally){

        var emailInput = remember { mutableStateOf("")}

        val context = LocalContext.current

        var code: String?

        Text(text = "Hello, it is Reservation app\n" +
                "If you have an account enter your email",
            textAlign = TextAlign.Center)

        Spacer(modifier = Modifier.height(30.dp))

        OutlinedTextField(
            singleLine = true,
            value = emailInput.value,
            shape = RoundedCornerShape(20.dp),
            onValueChange = {newText -> emailInput.value = newText},
            label = { Text(text = "example@some.com") },
            leadingIcon = {
                Icon(imageVector = Icons.Default.Email,
                    contentDescription = "email info")
            },
            keyboardOptions = KeyboardOptions.Default.copy(
                keyboardType = KeyboardType.Email,
                imeAction = ImeAction.Done
            ),
        )
        
        Spacer(modifier = Modifier.height(30.dp))

        Button(onClick = {

            viewModelMain.loginGetCode(emailInput.value)

            code = viewModelMain.loginProp
            if (code == "200"){
                Toast.makeText(context, viewModelMain.JWTtokenhere, Toast.LENGTH_SHORT).show()
                navController.navigate("ListPageScreen")
            }


        }) {
            Text(text = "Submit")
        }
        
        Spacer(modifier = Modifier.height(30.dp))

        ClickableText(
            text = AnnotatedString("Have no account? Go to registration page"),
            onClick = { navController.navigate("RegistrationScreen") },
            style = TextStyle(
                color = Color.Blue,
                fontSize = 15.sp
            )
        )

    }
}
