package com.example.reservationapp.screens


import android.widget.Toast
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.text.BasicText
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import com.example.reservationapp.viewmodels.NewViewModel

@Composable
fun OTPverify(navController: NavController, viewModelMain: NewViewModel){

    Column ( modifier = Modifier
        .fillMaxSize()
        .padding(horizontal = 30.dp, vertical = 140.dp),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally){

        Text(
            text = "Enter your code from email",
            textAlign = TextAlign.Center
        )

        Spacer(modifier = Modifier.height(30.dp))

        Box(modifier = Modifier.fillMaxSize(),
            contentAlignment = Alignment.Center){
            OtpTExtField()
        }

        Spacer(modifier = Modifier.height(30.dp))

    }

}

@Composable
fun OtpTExtField() {

    val context = LocalContext.current

    var otpText by remember {
        mutableStateOf("")
    }

    Column (
        verticalArrangement =  Arrangement.spacedBy(20.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        BasicTextField(
            readOnly = false,
            singleLine = true,
            value = otpText,
            maxLines = 1,
            keyboardOptions = KeyboardOptions(
                keyboardType = KeyboardType.Number,
            ),
            onValueChange = {

                if (it.length <= 4){
                    otpText = it
                }

                otpText = it
            }
        ){
            Row (horizontalArrangement =  Arrangement.spacedBy(10.dp)){
                repeat(4){ index ->
                    val number = when {
                        index >= otpText.length -> ""
                        else -> otpText[index]
                    }
                    Column (
                        verticalArrangement =  Arrangement.spacedBy(6.dp),
                        horizontalAlignment = Alignment.CenterHorizontally
                    ) {
                        Text(
                            text = number.toString(),
                            style = MaterialTheme.typography.titleLarge
                        )

                        Box( modifier = Modifier
                            .width(40.dp)
                            .height(2.dp)
                            .background(Color.Black) )

                    }
                }
            }

        }

        Button(
            onClick = {

                if (otpText != "0"){
                    Toast.makeText(context, otpText.toString(), Toast.LENGTH_SHORT).show()
                }

            }
        )  {
            Text(text = "Create OTP")

        }
    }


}

